#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ASSIGN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ASSIGN_HPP_INCLUDED

#include <boost/simd/memory/include/functions/scalar/assign.hpp>

#endif
